==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/FUELINVENTORYTANKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FUELINVENTORYTANKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FUELINVENTORYTANKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELINVENTORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELINVENTORYTANKLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUELINVENTORYTANKID_Type", propOrder = {
    "fuelinventorycode",
    "fuelinventorytanklinenum"
})
public class FUELINVENTORYTANKID_Type {

    @XmlElement(name = "FUELINVENTORYCODE", required = true)
    protected String fuelinventorycode;
    @XmlElement(name = "FUELINVENTORYTANKLINENUM")
    protected long fuelinventorytanklinenum;

    /**
     * Gets the value of the fuelinventorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUELINVENTORYCODE() {
        return fuelinventorycode;
    }

    /**
     * Sets the value of the fuelinventorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUELINVENTORYCODE(String value) {
        this.fuelinventorycode = value;
    }

    /**
     * Gets the value of the fuelinventorytanklinenum property.
     * 
     */
    public long getFUELINVENTORYTANKLINENUM() {
        return fuelinventorytanklinenum;
    }

    /**
     * Sets the value of the fuelinventorytanklinenum property.
     * 
     */
    public void setFUELINVENTORYTANKLINENUM(long value) {
        this.fuelinventorytanklinenum = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/FUELINVENTORYTANKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FUELINVENTORYTANKID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FUELINVENTORYTANKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELINVENTORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUELINVENTORYTANKLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUELINVENTORYTANKID_Type", propOrder = {
    "fuelinventorycode",
    "fuelinventorytanklinenum"
})
public class FUELINVENTORYTANKID_Type {

    @XmlElement(name = "FUELINVENTORYCODE", required = true)
    protected String fuelinventorycode;
    @XmlElement(name = "FUELINVENTORYTANKLINENUM")
    protected long fuelinventorytanklinenum;

    /**
     * Obtient la valeur de la propriété fuelinventorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUELINVENTORYCODE() {
        return fuelinventorycode;
    }

    /**
     * Définit la valeur de la propriété fuelinventorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUELINVENTORYCODE(String value) {
        this.fuelinventorycode = value;
    }

    /**
     * Obtient la valeur de la propriété fuelinventorytanklinenum.
     * 
     */
    public long getFUELINVENTORYTANKLINENUM() {
        return fuelinventorytanklinenum;
    }

    /**
     * Définit la valeur de la propriété fuelinventorytanklinenum.
     * 
     */
    public void setFUELINVENTORYTANKLINENUM(long value) {
        this.fuelinventorytanklinenum = value;
    }

}
